@@ -12,6 +12,7 @@ def create_request_log(
         status_code: int,
         request_body: bytes,
         message: str,
+        trace: str | None = None,
         error: Exception | None = None,
         ignore_fields: list[str] | None = None
 ) -> None:
@@ -35,7 +36,8 @@ def create_request_log(
     if error:
         data.update({
             "status_code": status_code,
-            "error": str(error)
+            "error": str(error),
+            "trace": trace[-1000:] if trace else None
         })
         logger.error(message, extra=data)
     else:
