@@ -11,10 +11,11 @@ def setup_logger(
         host: str,
         port: int,
         source: str,
-        ignore_fields: list[str] | None = None
+        ignore_fields: list[str] | None = None,
+        ignore_paths: list[str] | None = None
 ) -> None:
     logger = logging.getLogger('app')
     logger.setLevel(logging.INFO)
     handler = GELFUDPHandler(host, port, localname=source)
     logger.addHandler(handler)
-    app.add_middleware(LoggingMidlleware, ignore_fields=ignore_fields)
+    app.add_middleware(LoggingMidlleware, ignore_fields=ignore_fields, ignore_paths=ignore_paths)
